@@ -137,6 +137,10 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     # read and filter prompt type
     df_raw = pd.read_csv(csv_path[0])
     df_raw = df_raw[columns_list]
+
+    if "Reprompt2_Prompt_UnixTime " in df_raw.columns:
+        df_raw = df_raw.rename(columns={"Reprompt2_Prompt_UnixTime ": "Reprompt2_Prompt_UnixTime"})
+
     df_raw = df_raw[~df_raw.Prompt_Type.isin(prompt_type_excluded)]
     df_raw.reset_index(drop=True, inplace=True)
 
